==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/acl/lang/uk/lang.php <==
<?php
/**
 * ukrainian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Oleksiy Voronin <ovoronin@gmail.com>
 * @author serg_stetsuk@ukr.net
 */
$lang['admin_acl']             = 'Керування списками контролю доступу';
$lang['acl_group']             = 'Група';
$lang['acl_user']              = 'Користувач';
$lang['acl_perms']             = 'Права доступу для';
$lang['page']                  = 'Сторінка';
$lang['namespace']             = 'Простір імен';
$lang['btn_select']            = 'Вибрати';
$lang['p_user_id']             = 'Користувач <b class="acluser">%s</b> зараз має такі права доступу до сторінки <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Користувач <b class="acluser">%s</b> зараз має такі права доступу до простору імен <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Члени групи <b class="aclgroup">%s</b> зараз мають такі права для сторінки <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Члени групи <b class="aclgroup">%s</b> зараз мають такі права доступу до простору імен <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Будь-ласка <b>введіть користувача або групу<b> у вікно зверху, щоб подивитися чи редагувати права доступу до сторінки <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Будь-ласка <b>введіть користувача або групу<b> у вікно зверху, щоб подивитися чи редагувати права доступу до сторінки <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Увага: Права доступу не встановлені явно, але наслідуються від інших груп чи вищих просторів імен';
$lang['p_isadmin']             = 'Увага: Обрані група чи користувач завжди мають повні права доступу, оскільки вони є суперкористувачами';
$lang['current']               = 'Поточні правила ACL';
$lang['where']                 = 'Сторінка/Простір імен';
$lang['who']                   = 'Користувач/Група';
$lang['perm']                  = 'Дозволи';
$lang['acl_perm0']             = 'Жодних';
$lang['acl_perm1']             = 'Читання';
$lang['acl_perm2']             = 'Редагування';
$lang['acl_perm4']             = 'Створення';
$lang['acl_perm8']             = 'Завантаження';
$lang['acl_perm16']            = 'Вилучення';
$lang['acl_new']               = 'Додати новий запис';
$lang['acl_mod']               = 'Змінити запис';

==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/lib/plugins/acl/lang/uk/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Oleksiy Voronin <ovoronin@gmail.com>
 * @author serg_stetsuk@ukr.net
 * @author okunia@gmail.com
 * @author Oleksandr Kunytsia <okunia@gmail.com>
 * @author Uko uko@uar.net
 * @author Ulrikhe Lukoie  <lukoie@gmail>.com
 */
$lang['admin_acl']             = 'Керування списками контролю доступу';
$lang['acl_group']             = 'Група';
$lang['acl_user']              = 'Користувач';
$lang['acl_perms']             = 'Права доступу для';
$lang['page']                  = 'Сторінка';
$lang['namespace']             = 'Простір імен';
$lang['btn_select']            = 'Вибрати';
$lang['p_user_id']             = 'Користувач <b class="acluser">%s</b> зараз має такі права доступу до сторінки <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Користувач <b class="acluser">%s</b> зараз має такі права доступу до простору імен <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Члени групи <b class="aclgroup">%s</b> зараз мають такі права для сторінки <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Члени групи <b class="aclgroup">%s</b> зараз мають такі права доступу до простору імен <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Будь-ласка <b>введіть користувача або групу<b> в поле зверху, щоб подивитися чи змінити права доступу до сторінки <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Будь-ласка <b>введіть користувача або групу<b> у вікно зверху, щоб подивитися чи змінити права доступу до сторінки <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Зверніть увагу! Права доступу, не встановлені явно, наслідуються від інших груп чи вищих просторів імен.';
$lang['p_isadmin']             = 'Зверніть увагу! Обрані група чи користувач завжди мають повні права доступу, оскільки вони є суперкористувачами.';
$lang['p_include']             = 'Старші права доступу включають молодші. Створення, Завантаження і Вилучення застосовні лише до просторів імен.';
$lang['current']               = 'Поточні правила ACL';
$lang['where']                 = 'Сторінка/Простір імен';
$lang['who']                   = 'Користувач/Група';
$lang['perm']                  = 'Права доступу';
$lang['acl_perm0']             = 'Жодних';
$lang['acl_perm1']             = 'Читання';
$lang['acl_perm2']             = 'Редагування';
$lang['acl_perm4']             = 'Створення';
$lang['acl_perm8']             = 'Завантаження';
$lang['acl_perm16']            = 'Вилучення';
$lang['acl_new']               = 'Додати новий запис';
$lang['acl_mod']               = 'Змінити запис';
